Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4466)

Unified Diff: chrome/renderer/resources/extensions/notifications_custom_bindings.js

Issue 12313115: Take notification API out of experimental. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix merge conflict. Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/renderer/resources/extensions/notifications_custom_bindings.js
diff --git a/chrome/renderer/resources/extensions/notification_custom_bindings.js b/chrome/renderer/resources/extensions/notifications_custom_bindings.js
similarity index 93%
rename from chrome/renderer/resources/extensions/notification_custom_bindings.js
rename to chrome/renderer/resources/extensions/notifications_custom_bindings.js
index db042b16a677a93601d3f2832f9d0953a3acacbc..a2013bdd149ad2f82a72512d0878fd5c1fa6fc26 100644
--- a/chrome/renderer/resources/extensions/notification_custom_bindings.js
+++ b/chrome/renderer/resources/extensions/notifications_custom_bindings.js
@@ -2,9 +2,9 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// Custom bindings for the notification API.
+// Custom bindings for the notifications API.
-var binding = require('binding').Binding.create('experimental.notification');
+var binding = require('binding').Binding.create('notifications');
var sendRequest = require('sendRequest').sendRequest;
var imageUtil = require('imageUtil');
@@ -123,12 +123,12 @@ function genHandle(failure_function) {
var handleCreate = genHandle(function(callback, id) { callback(id); });
var handleUpdate = genHandle(function(callback, id) { callback(false); });
-var experimentalNotificationCustomHook = function(bindingsAPI, extensionId) {
+var notificationsCustomHook = function(bindingsAPI, extensionId) {
var apiFunctions = bindingsAPI.apiFunctions;
apiFunctions.setHandleRequest('create', handleCreate);
apiFunctions.setHandleRequest('update', handleCreate);
};
-binding.registerCustomHook(experimentalNotificationCustomHook);
+binding.registerCustomHook(notificationsCustomHook);
exports.binding = binding.generate();
« no previous file with comments | « chrome/renderer/resources/extensions/notification_custom_bindings.js ('k') | chrome/renderer/resources/renderer_resources.grd » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698